// This program reads grades and weights from stdin and prints the weighted
// average grade computed as follows: it tries omitting each item, and
// determines which omission maximizes the weighted average. It prints the
// average followed by the 0-based index of the omitted item.

#include <cstdlib>
#include <iostream>
#include <stdexcept>
#include <vector>

// A weighted grade consists of the raw grade and a weight that determines
// its value relative to other grades.
struct Weighted_grade
{
    double grade;
    double weight;
};

// Thrown when the average is undefined because the total weight is 0.
struct average_undefined : std::runtime_error {
    average_undefined() : runtime_error("Average undefined") { }
};

// Thrown when the input doesn't make sense because it contains a negative
// weight.
struct negative_weight : std::runtime_error {
    negative_weight() : runtime_error("Negative weight") { }
};

// The result of computing which grade to omit: the best average and the
// index of the omitted grade.
struct Omission_result
{
    double average;
    int index;
};

// Reads a vector of weighted grades from cin, stopping when it encounters a
// non-number of EOF. Each weighted grade is read as the raw grade followed
// by the weight.
std::vector<Weighted_grade> read_grades()
{
    std::vector<Weighted_grade> result;
    Weighted_grade wg;

    while (std::cin >> wg.grade && std::cin >> wg.weight) {
        result.push_back(wg);
    }

    return result;
}

// Computes the weighted sum of a vector of weighted grades; that is, the sum
// of each grade times its weight.
double weighted_sum(std::vector<Weighted_grade> grades)
{
    double sum = 0;

    for (Weighted_grade wg : grades) {
        if (wg.weight < 0) throw negative_weight();

        sum += wg.weight * wg.grade;
    }

    return sum;
}

// Computes the sum of all weights in a vector of weighted grades.
double total_weight(std::vector<Weighted_grade> grades)
{
    double sum = 0;

    for (Weighted_grade wg : grades) {
        sum += wg.weight;
    }

    return sum;
}

// Computes the weighted sum of a vector with the indicated element omitted.
double weighted_sum_without(std::vector<Weighted_grade> grades,
                            int which)
{
    double dropped = grades[which].weight * grades[which].grade;
    return weighted_sum(grades) - dropped;
}

// Computes the sum of the weights of a vector with the indicated element
// omitted.
double total_weight_without(std::vector<Weighted_grade> grades, int which)
{
    double dropped = grades[which].weight;
    return total_weight(grades) - dropped;
}

// Computes weighted average; throws average_undefined if total weight is 0.
double weighted_average_without(std::vector<Weighted_grade> grades, int which)
{
    double numerator = weighted_sum_without(grades, which);
    double denominator = total_weight_without(grades, which);

    if (denominator == 0) throw average_undefined();

    return numerator / denominator;
}

// Finds the best grade to omit and the resulting best average.
Omission_result find_best_omission(std::vector<Weighted_grade> grades)
{
    Omission_result best { 0.0, -1 };

    for (int i = 0; i < grades.size(); ++i) {
        try {
            double average = weighted_average_without(grades, i);
            if (average > best.average) {
                best.index = i;
                best.average = average;
            }
        } catch (average_undefined&) { }
    }

    if (best.index == -1) throw average_undefined();

    return best;
}

// Prints the omission result: the best average followed by the omitted index.
void print_omission_result(Omission_result result)
{
    std::cout << result.average << ' ' << result.index << '\n';
}

int main()
try {
    std::vector<Weighted_grade> grades = read_grades();
    Omission_result best = find_best_omission(grades);
    print_omission_result(best);
}

catch (average_undefined&) {
    std::cerr << "No average because total weight is 0.\n";
}

catch (std::runtime_error& e) {
    std::cerr << "Runtime error in main: " << e.what() << '\n';
}
